#input subject, time, test and ref concentration
RepNCAdata<-function()
{
NCAdata(replicated=TRUE, parallel=FALSE)
}